/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2007-2008 - INRIA - Vincent COUVERT
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

#ifndef __CONSOLEREAD_H__
#define __CONSOLEREAD_H__
/*--------------------------------------------------------------------------*/
#include "dynlib_console.h"
/**
* ConsoleRead function
* @return characters read in console
*/
CONSOLE_IMPEXP char *ConsoleRead(void);

/*--------------------------------------------------------------------------*/
#endif /* __CONSOLEREAD_H__ */

